from os.path import join, abspath, dirname

DEFAULT_WORKING_DIRECTORY = "."
DEFAULT_FLIES_INTERMEDIATE = "FLiES_intermediate"

GEOS5FP_DIRECTORY = "~/data/GEOS5FP_download"

DEFAULT_MODEL_FILENAME = join(abspath(dirname(__file__)), "FLiESANN.h5")
SPLIT_ATYPES_CTYPES = True

DEFAULT_PREVIEW_QUALITY = 20
DEFAULT_INCLUDE_PREVIEW = True
DEFAULT_RESAMPLING = "cubic"
DEFAULT_SAVE_INTERMEDIATE = True
DEFAULT_SHOW_DISTRIBUTION = True
DEFAULT_DYNAMIC_ATYPE_CTYPE = False
